@@ -8,7 +8,7 @@ fn round_up_to_nearest_multiple(val: i128, multiple: i128) -> i128 {
 
     ((val + ss) / multiple) * multiple
 }
-
+/*
 ///
 /// Returns where the first tick should be, as well as how many ticks there are
 ///
@@ -32,7 +32,9 @@ fn get_range_info(step: i128, range_all: [i128; 2]) -> (i128, u32) {
 
     (start_step, step_num)
 }
+*/
 
+/*
 ///
 /// INPUT:
 /// Ideal number of ticks
@@ -58,6 +60,7 @@ fn find_good_step(good_steps: &[u32], ideal_num_steps: u32, range_all: [i128; 2]
 
     (best.0 as i128 * step_power, best.0)
 }
+*/
 
 ///
 /// Default integer context. It will attempt to find reasonable step sizes, and format them as regular integers.
@@ -100,7 +103,24 @@ impl PlotNumContext for IntegerContext {
         range: [i128; 2],
         dash: DashInfo,
     ) -> TickInfo<i128, i128> {
-        let good_ticks = &[1, 2, 5, 10];
+        let tick_layout = TickLayout::new(&[1, 2, 5], ideal_num_steps, range);
+
+        let (display_relative, ticks) = tick_layout.generate();
+
+        let dash_size = Some(compute_best_dash_1_2_5(
+            self.scale(tick_layout.step, range, dash.max),
+            dash.ideal_dash_size,
+            tick_layout.normalized_step,
+        ));
+
+        TickInfo {
+            unit_data: tick_layout.step,
+            ticks,
+            display_relative,
+            dash_size,
+        }
+        /*
+        let good_ticks = &[1, 2, 5];
 
         let (step, good_normalized_step) = find_good_step(good_ticks, ideal_num_steps, range);
         let (start_step, step_num) = get_range_info(step, range);
@@ -121,36 +141,19 @@ impl PlotNumContext for IntegerContext {
             ticks.push(Tick { position, value });
         }
 
-        let dash_size = {
-            let dash_multiple = good_normalized_step;
-            let max = dash.max;
-            let ideal_dash_size = dash.ideal_dash_size;
-            let one_step = self.scale(step, range, max);
-
-            assert!(dash_multiple > 0);
-
-            if dash_multiple == 1 || dash_multiple == 10 {
-                let a = test_multiple(ideal_dash_size, one_step, 2, range, max).unwrap();
-                let b = test_multiple(ideal_dash_size, one_step, 5, range, max).unwrap();
-                if (a - ideal_dash_size).abs() < (b - ideal_dash_size).abs() {
-                    Some(a)
-                } else {
-                    Some(b)
-                }
-            } else {
-                Some(test_multiple(ideal_dash_size, one_step, dash_multiple, range, max).unwrap())
-            }
-        };
-
-        //let dash_size = None;
+        let dash_size = Some(compute_best_dash_1_2_5(
+            self.scale(step, range, dash.max),
+            dash.ideal_dash_size,
+            good_normalized_step,
+        ));
 
         TickInfo {
             unit_data: step,
             ticks,
             dash_size,
-            //dash_size,
             display_relative: display_relative.then(|| start_step),
         }
+        */
     }
 
     fn unit_range(&mut self, offset: Option<i128>) -> [i128; 2] {
@@ -168,117 +171,92 @@ impl HasDefaultContext for i128 {
 
 impl PlotNum for i128 {}
 
-/*
-pub use month::MonthIndex;
-mod month {
-    use super::*;
+pub struct TickLayout {
+    step: i128,
+    start_tick: i128,
+    num_steps: u32,
+    normalized_step: u32,
+}
+impl TickLayout {
+    fn generate(&self) -> (Option<i128>, Vec<Tick<i128>>) {
+        let (display_relative, first_tick) = {
+            let tick_layout = self;
+            let end =
+                tick_layout.start_tick + ((tick_layout.num_steps - 1) as i128) * tick_layout.step;
 
-    ///
-    /// A wrapper type that displays ticks at intervals that make sense for indexing to months.
-    /// Ticks will appear at 1,2,6,12 instead of 1,2,5,10.
-    /// See the month example.
-    ///
-    #[derive(Debug, Copy, Clone, PartialEq, PartialOrd)]
-    pub struct MonthIndex(pub i128);
+            let mut start_s = String::new();
+            let mut end_s = String::new();
 
-    impl fmt::Display for MonthIndex {
-        fn fmt(&self, a: &mut fmt::Formatter) -> fmt::Result {
-            write!(a, "{}", self.0)
-        }
-    }
-    impl PlotNum for MonthIndex {
-        type UnitData = <i128 as PlotNum>::UnitData;
-        fn compute_ticks(ideal_num_steps: u32, range: [Self; 2],dash:DashInfo) -> TickInfo<Self, Self::UnitData> {
-            let cc = [1, 2, 6, 12].iter().map(|&step| {
-                let (a, num_steps) = get_range_info(step, [range[0].0, range[1].0]);
-                (
-                    step,
-                    a,
-                    num_steps,
-                    (ideal_num_steps as i32 - num_steps as i32).abs(),
-                )
-            });
+            util::write_interval_float(
+                &mut start_s,
+                tick_layout.start_tick as f64,
+                Some(tick_layout.step as f64),
+            )
+            .unwrap();
+            util::write_interval_float(&mut end_s, end as f64, Some(tick_layout.step as f64))
+                .unwrap();
 
-            let (step, start_step, num_steps, _) = cc.min_by(|a, b| a.3.cmp(&b.3)).unwrap();
-
-            let mut ticks = Vec::with_capacity(usize::try_from(num_steps).unwrap());
-            for a in 0..num_steps {
-                let position = MonthIndex(start_step + step * (a as i128));
-                ticks.push(Tick {
-                    position,
-                    value: position,
-                });
-            }
-
-            let dash_multiple = step as u32;
-
-            let step = MonthIndex(step);
-            let start_step = MonthIndex(start_step);
-
-            assert!(ticks.len() >= 2);
-
-            TickInfo {
-                unit_data: StepAmount(step.0),
-                ticks,
-                //dash_multiple,
-                display_relative: None,
-            }
-        }
-
-        fn unit_range(offset: Option<Self>) -> [Self; 2] {
-            if let Some(o) = offset {
-                [MonthIndex(o.0 - 1), MonthIndex(o.0 + 1)]
+            if start_s.len() > 7 || end_s.len() > 7 {
+                (Some(tick_layout.start_tick), 0)
             } else {
-                [MonthIndex(-1), MonthIndex(1)]
+                (None, tick_layout.start_tick)
             }
+        };
+
+        let mut ticks = Vec::with_capacity(usize::try_from(self.num_steps).unwrap());
+        for a in 0..self.num_steps {
+            let position = self.start_tick + self.step * (a as i128);
+            let value = first_tick + self.step * (a as i128);
+
+            ticks.push(Tick { position, value });
         }
+        (display_relative, ticks)
+    }
 
-        fn fmt_tick(
-            &self,
-            formatter: &mut std::fmt::Formatter,
-            step: Self::UnitData,
-            fmt: FmtFull,
-        ) -> std::fmt::Result {
-            tick_fmt::write_interval_i128(formatter, self.0, None)
-        }
+    fn new(good_steps: &[u32], ideal_num_steps: u32, range_all: [i128; 2]) -> TickLayout {
+        let ideal_num_steps = ideal_num_steps.max(2);
 
-        fn scale(&self, val: [Self; 2], max: f64) -> f64 {
-            let diff = (val[1].0 - val[0].0) as f64;
+        let range = range_all[1] - range_all[0];
 
-            let scale = max / diff;
+        let rough_step = range as f64 / (ideal_num_steps - 1) as f64;
 
-            (self.0) as f64 * scale
-        }
+        //TODO replace with integer log
+        let step_power = 10.0f64.powf((rough_step as f64).log10().floor()).ceil() as i128;
 
-        fn dash_size(
-            ideal_dash_size: f64,
-            tick_info: &TickInfo<Self, Self::UnitData>,
-            range: [Self; 2],
-            max: f64,
-        ) -> Option<f64> {
-            None
-            /*
-            let one_step = tick_info.step.scale(range, max);
-            let mut dash_multiple = tick_info.dash_multiple;
+        let cc = good_steps.iter().map(|&normalized_step| {
+            assert!(normalized_step > 0);
+            let step = normalized_step as i128 * step_power;
 
-            assert!(dash_multiple > 0);
+            let start_tick = round_up_to_nearest_multiple(range_all[0], step);
 
-            if dash_multiple == 1 || dash_multiple == 12 {
-                dash_multiple = 6;
-            }
+            let num_steps = {
+                let mut counter = start_tick;
+                let mut res = 0;
+                for a in 0.. {
+                    if counter > range_all[1] {
+                        res = a;
+                        break;
+                    }
 
-            for x in 1..50 {
-                let dash_size = one_step / ((dash_multiple.pow(x)) as f64);
-                if dash_size < ideal_dash_size {
-                    return Some(dash_size);
+                    assert!(step + counter > counter, "{:?}", (step, range_all));
+                    counter += step;
                 }
-            }
-            unreachable!(
-                "Could not find a good dash step size! {:?}",
-                (one_step, dash_multiple, ideal_dash_size)
-            );
-            */
-        }
+                res
+            };
+
+            let res = TickLayout {
+                step,
+                normalized_step,
+                num_steps,
+                start_tick,
+            };
+
+            (res, (num_steps as i32 - ideal_num_steps as i32).abs())
+        });
+
+        let best = cc.min_by(|a, b| a.1.cmp(&b.1)).unwrap();
+        let best = best.0;
+        assert!(best.num_steps >= 2);
+        best
     }
 }
-*/
